/*********** commonvars.h
		Common variables of the nlist mailing list program.
		This file is included into every module using the common
		variables. Only one module define N_EXTERN as empty string,
		all the others assign "extern" value to this macro.
		
			Written by Gabor Paller
		
							**********/
#include <setjmp.h>
#include <stdio.h>
#include	"imports.h"

/* Error names */
#define	FINISH_OK		1
#define GENERAL_ERROR		2
#define	BAD_SUBSCRIBE		3
#define ALREADY_ON_LIST		4
#define LIST_DISABLED		5
#define NOT_ALLOWED		6	/* Subscription not allowed */
#define SEND_SUBS_MESSAGE	7
#define BAD_UNSUBSCRIBE		8
#define SEND_UNSUBS_MESSAGE	9
#define HELP_MESSAGE		10
#define NO_LIST			11	/* No such list */
#define NOT_ON_LIST		12
#define SEND_CONF_MESSAGE	13
#define	LIST_CLOSED		14

/**************** common variables ************************/
							
/* True if the list can be used only by subscribed members */
N_EXTERN	bool	closed;
/* True if subscribe and unsubscribe is allowed */
N_EXTERN	bool	subscribe;
/* True if sender banner is allowed */
N_EXTERN	bool	sender_banner;
/* Contains the reply-to address if set */
N_EXTERN	char	replyto[N_BUFSIZE];
/* Archive directory */
N_EXTERN	char	archive[N_BUFSIZE];
/* Name of the SMTP server */
N_EXTERN	char	smtp_server[N_BUFSIZE];
/* Errors-To: address */
N_EXTERN	char	errors_to[N_BUFSIZE];
/* To: address */
N_EXTERN	char	to_address[N_BUFSIZE];
/* From: address */
N_EXTERN	char	from_address[N_BUFSIZE]; 
/* Address of the list */
N_EXTERN	char	list_address[N_BUFSIZE];
/* Domain name of the SMTP server */
N_EXTERN	char	domain_name[N_BUFSIZE];
/* List title */
N_EXTERN	char	list_title[N_BUFSIZE];
/* Original subject string */
N_EXTERN	char	orig_subject_string[N_BUFSIZE];
/* Subject work string */
N_EXTERN	char	subject_string[N_BUFSIZE];
/* Full address of the sender */
N_EXTERN	char *sender_full_address;
/* Content type of the letter (if any) */
N_EXTERN	char content_type[2*N_BUFSIZE];
/* Boundary string (if present) */
N_EXTERN	char boundary[N_BUFSIZE];

/* Buffer variable */
N_EXTERN	char	work[2*N_BUFSIZE];

/* File name buffer */
N_EXTERN	char	fname[N_BUFSIZE];

/* Name of the list */
N_EXTERN	char	list_name[N_BUFSIZE];

/* TRUE if control mode */
N_EXTERN	int	control_mode;

/* Error handling setjmp buffer */
N_EXTERN	jmp_buf	finish;

/* We keep the config file pointer here so that we can make proper
   lock/unlock */
N_EXTERN	FILE	*config;

/* Pointer to the sender address from the From field */
N_EXTERN	char *addr;

/* Pointer to the subject field */
N_EXTERN	char *subject;

/* Name of the temporary file that stores the message */
N_EXTERN	char	TempFileName[N_BUFSIZE];

/* Name of the secondary temporary file */
N_EXTERN	char	TempFileName2[N_BUFSIZE];

/* content transfer encoding */
N_EXTERN	char	*content_encoding;

/* Pointer to the beginning of the content in the temporary file */
N_EXTERN	long	ContentPointer;

/* Timeout in seconds for config file lock */
N_EXTERN	long	ConfigLockTimeout;

/* Name of the log file */
N_EXTERN	char	LogFileName[N_BUFSIZE];

/* Logging level */
N_EXTERN	int	LogLevel;

/* Logging on/off */
N_EXTERN	bool	LogEnable;

/* Enable logging of mailloop messages */
N_EXTERN	bool	LogMailLoop;

/* Enable auto-unsubscribe */
N_EXTERN	bool	AutoUnsubscribe;

/* NNTP newsgroup name */
N_EXTERN	char	nntp_newsgroup[N_BUFSIZE];

/* NNTP server name */
N_EXTERN	char	nntp_server[N_BUFSIZE];

/* NNTP spool directory for articles whose posting failed */
N_EXTERN	char	nntp_spooldir[N_BUFSIZE];

/* NNTP port number */
N_EXTERN	int	nntp_port;

/* NNTP list address */
N_EXTERN	char	nntp_list_address[N_BUFSIZE];

/* NNTP from address */
N_EXTERN	char	nntp_from_address[N_BUFSIZE];

/* NNTP replyto address */
N_EXTERN	char	nntp_replyto[N_BUFSIZE];

/* TRUE if binary attachments shouldn't be posted to the newsgroup */
N_EXTERN	bool	nntp_nobinary;

/* Name of the protocol in use (for logging purposes) */
N_EXTERN	char	protstr[8];

/* Enable subscription-confirmation feature */
N_EXTERN	bool	SubsConfirmation;

/* Timeout for the subscription confirmation */
N_EXTERN	int	SubsConfTimeout;

/* Confirmation ID generated for the current subscription message */
N_EXTERN	char	SubsConfID[N_BUFSIZE];

/* Enable news-to-list relay */
N_EXTERN	bool	nntp_newstolist;

/* Determines nlistd timeout for newsgroup checking */
N_EXTERN	int	nntp_newschecktime;

/* Determines the length of the message window. */
N_EXTERN	int	nntp_msgwindow;

/* Determines the message expiration time */
N_EXTERN	int	nntp_msgexpiration;

/* nlist process umask */
N_EXTERN	int	nlist_umask;

/* file extensions to be filtered out */
N_EXTERN	char	filter_extensions[N_BUFSIZE];

/* Name of the HTML file where the archive directory is placed */
N_EXTERN	char	monthindex_name[N_BUFSIZE];

/* new article access method for nlistd */
N_EXTERN	int	nntp_newart_access;
#define		NEWART_NEWNEWS	1	/* Access by NEWNEWS */
#define		NEWART_STAT	2	/* Access by STAT */

/* Passphrase table for semi-closed lists */
#define		MAX_PASSPHRASE	10
#define		PASSPHRASE_MAXLEN	50
N_EXTERN	char passphrase[MAX_PASSPHRASE][PASSPHRASE_MAXLEN];

/* Determines whether e-mail addresses should be garbled for newsgroups
   and web archive */
N_EXTERN	int	garble_flag;
 